# Third-Party Licenses

CMakeHub includes CMake modules from third-party repositories. Each module maintains its original license.

## Summary

| License | Module Count |
|---------|--------------|
| Apache-2.0 | 2 |
| BSD3 | 1 |
| BSL-1.0 | 1 |
| Boost | 3 |
| MIT | 41 |

## Detailed Module List

### Apache-2.0

| Module | Repository | Author |
|--------|-----------|--------|
| c_standards | [https://github.com/StableCoder/cmake-scripts.git](https://github.com/StableCoder/cmake-scripts.git) | StableCoder |
| cpp_standards | [https://github.com/StableCoder/cmake-scripts.git](https://github.com/StableCoder/cmake-scripts.git) | StableCoder |

### BSD3

| Module | Repository | Author |
|--------|-----------|--------|
| android_toolchain | [https://github.com/taka-no-me/android-cmake.git](https://github.com/taka-no-me/android-cmake.git) | taka-no-me |

### BSL-1.0

| Module | Repository | Author |
|--------|-----------|--------|
| catch2_cmake | [https://github.com/catchorg/Catch2.git](https://github.com/catchorg/Catch2.git) | catchorg |

### Boost

| Module | Repository | Author |
|--------|-----------|--------|
| compiler_info | [https://github.com/rpavlik/cmake-modules.git](https://github.com/rpavlik/cmake-modules.git) | rpavlik |
| launchers | [https://github.com/rpavlik/cmake-modules.git](https://github.com/ravlik/cmake-modules.git) | rpavlik |
| use_folders | [https://github.com/rpavlik/cmake-modules.git](https://github.com/rpavlik/cmake-modules.git) | rpavlik |

### MIT

| Module | Repository | Author |
|--------|-----------|--------|
| add_gtest | [https://github.com/CLIUtils/cmake.git](https://github.com/CLIUtils/cmake.git) | CLIUtils |
| afl_fuzzing | [https://github.com/StableCoder/cmake-scripts.git](https://github.com/StableCoder/cmake-scripts.git) | StableCoder |
| clang_tidy_cg | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| clang_tidy_tools | [https://github.com/StableCoder/cmake-scripts.git](https://github.com/StableCoder/cmake-scripts.git) | StableCoder |
| code_coverage_bilke | [https://github.com/bilke/cmake-modules.git](https://github.com/bilke/cmake-modules.git) | bilke |
| code_formatter | [https://github.com/StableCoder/cmake-scripts.git](https://github.com/StableCoder/cmake-scripts.git) | StableCoder |
| compile_options | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| compiler_warnings | [https://github.com/StableCoder/cmake-scripts.git](https://github.com/StableCoder/cmake-scripts.git) | StableCoder |
| component_install | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| conan | [https://github.com/conan-io/cmake-conan.git](https://github.com/conan-io/cmake-conan.git) | conan-io |
| cotire | [https://github.com/sakra/cotire.git](https://github.com/sakra/cotire.git) | sakra |
| coverage | [https://github.com/bilke/cmake-modules.git](https://github.com/bilke/cmake-modules.git) | bilke |
| coverage_cg | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| cpm | [https://github.com/cpm-cmake/CPM.cmake.git](https://github.com/cpm-cmake/CPM.cmake.git) | cpm-cmake |
| cppcheck_cg | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| cuda | [https://github.com/CLIUtils/cmake.git](https://github.com/CLIUtils/cmake.git) | CLIUtils |
| dependency_graph | [https://github.com/StableCoder/cmake-scripts.git](https://github.com/StableCoder/cmake-scripts.git) | StableCoder |
| doctest | [https://github.com/doctest/doctest.git](https://github.com/doctest/doctest.git) | doctest |
| doxygen_helper | [https://github.com/StableCoder/cmake-scripts.git](https://github.com/StableCoder/cmake-scripts.git) | StableCoder |
| export_header | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| find_assimp | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| find_egl | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| find_ffmpeg | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| find_glesv2 | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| find_glew | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| find_gtk3 | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| find_gtk4 | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| find_hidapi | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| find_nodejs | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| find_or_build_gtest | [https://github.com/viaduck/cmake-modules.git](https://github.com/viaduck/cmake-modules.git) | viaduck |
| find_sdl2 | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| gcov | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| git_version | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| glsl_shaders | [https://github.com/StableCoder/cmake-scripts.git](https://github.com/StableCoder/cmake-scripts.git) | StableCoder |
| install_helpers | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| ios_toolchain | [https://github.com/leetal/ios-cmake.git](https://github.com/leetal/ios-cmake.git) | leetal |
| lto_optimization | [https://github.com/StableCoder/cmake-scripts.git](https://github.com/StableCoder/cmake-scripts.git) | StableCoder |
| precompiled_header | [https://github.com/larsch/cmake-precompiled-header.git](https://github.com/larsch/cmake-precompiled-header.git) | larsch |
| qt_helper | [https://github.com/dcourtois/CMakeUtils.git](https://github.com/dcourtois/CMakeUtils.git) | dcourtois |
| runtime_dependencies | [https://github.com/cginternals/cmake-init.git](https://github.com/cginternals/cmake-init.git) | cginternals |
| sanitizers | [https://github.com/arsenm/sanitizers-cmake.git](https://github.com/arsenm/sanitizers-cmake.git) | arsenm |
